====================
Oslo Context Library
====================

The Oslo context library has helpers to maintain useful information
about a request context. The request context is usually populated in
the WSGI pipeline and used by various modules such as logging.

* License: Apache License, Version 2.0
* Documentation: https://docs.openstack.org/oslo.context/latest/
* Source: https://opendev.org/openstack/oslo.context
* Bugs: https://bugs.launchpad.net/oslo.context
* Release notes:  https://docs.openstack.org/releasenotes/oslo.context/

Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/oslo.context.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. Change things from this point on

.. image:: https://img.shields.io/pypi/v/oslo.context.svg
    :target: https://pypi.org/project/oslo.context/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/dm/oslo.context.svg
    :target: https://pypi.org/project/oslo.context/
    :alt: Downloads
